NAME = 'fadapa'
VERSION = '0.2'
DESCRIPTION = 'A minimal parser to parse FastQC output data in Python'
LONG_DESCRIPTION = '''Fadapa is a minimal parser for parsing Fastqc data. Using this module parsing FastQC results is quite easy and simple.'''
AUTHOR = 'Anand Reddy Pandikunta'
EMAIL = 'anand21nanda@gmail.com'
COPYRIGHT = 'Uncopyrighted'
URL = 'https://github.com/fadapa/fadapa'
LICENSE = 'Uncopyrighted'

__all__ = ('NAME', 'VERSION', 'DESCRIPTION', 'LONG_DESCRIPTION', 'AUTHOR', 'EMAIL', 'COPYRIGHT', 'URL', 'LICENSE')
